;; ┌─┐┬─┐┌─┐┌─┐┬ ┬┬┌─┐┌─┐
;; │ ┬├┬┘├─┤├─┘├─┤││  └─┐
;; └─┘┴└─┴ ┴┴  ┴ ┴┴└─┘└─┘
;;       ┌─┐┌┐┌┌┬┐       
;;       ├─┤│││ ││       
;;       ┴ ┴┘└┘─┴┘       
;;     ┌┬┐┌─┐┌┬┐┌─┐      
;;      ││├─┤ │ ├─┤      
;;     ─┴┘┴ ┴ ┴ ┴ ┴      

;; load in the s-exp of graphics and pet data

(load "~/hobbies/uwu/version-1/uwu-graphics.el")

;; ┬┌─┌─┐┬ ┬┌┬┐┌─┐┌─┐
;; ├┴┐├┤ └┬┘│││├─┤├─┘
;; ┴ ┴└─┘ ┴ ┴ ┴┴ ┴┴  

(defvar uwu-mode-map
  (let ((map (make-sparse-keymap)))
    ;; scroll back one pet, inside the pet viewer
    (define-key map (kbd "a") #'uwu--previous-pet)
    (define-key map (kbd "s") #'uwu--next-pet)
    map)
  "Keymap for `uwu-mode'.")

;; ┌┬┐┌─┐ ┬┌─┐┬─┐ 
;; │││├─┤ ││ │├┬┘ 
;; ┴ ┴┴ ┴└┘└─┘┴└─ 
;; ┌┬┐┌─┐┌┬┐┌─┐   
;; ││││ │ ││├┤    
;; ┴ ┴└─┘─┴┘└─┘   
;; ┌─┐┌─┐┌┬┐┬ ┬┌─┐
;; └─┐├┤  │ │ │├─┘
;; └─┘└─┘ ┴ └─┘┴  

(defgroup uwu nil
  "A virtual pet simulator."
  :group 'applications)

(defcustom uwu-mode-hook nil
  "Hook run when entering uwu mode."
  :type 'hook
  :group 'uwu)

(define-derived-mode uwu-mode fundamental-mode "uwu"
  "The major mode of the uwu virtual pet simulator")

;; ┬  ┬┌─┐┬─┐┬┌─┐┌┐ ┬  ┌─┐┌─┐
;; └┐┌┘├─┤├┬┘│├─┤├┴┐│  ├┤ └─┐
;;  └┘ ┴ ┴┴└─┴┴ ┴└─┘┴─┘└─┘└─┘

(defvar *pet-shop-choice* nil)

;; ┌─┐┬ ┬┌┐┌┌─┐┌┬┐┬┌─┐┌┐┌┌─┐
;; ├┤ │ │││││   │ ││ ││││└─┐
;; └  └─┘┘└┘└─┘ ┴ ┴└─┘┘└┘└─┘

(defun pet-movement (pet-gfx)

  (let ((rng-move (random 5)))

    (cond ((and
	    (= 3 rng-move)
	    (> movement 0))

	   (decf movement))

	  (
	   (and
	    (= 4 rng-move)
	    (< movement 9))

	   (incf movement)))

    (princ "╔═════════════════════╗" (get-buffer "*scratch*"))
    
    (print
     (concat
      (substring "         " movement)

      (nth
       rng-move
       (cdr pet-gfx))) ; here we use the CDR of the gfx key-value
		       ; field, which gives us the graphics, and
		       ; eliminates the 'key' element.
     
     (get-buffer "*scratch*"))


    (print "╚═════════════════════╝" (get-buffer "*scratch*"))))

(defun blank-and-draw-frame (pet-gfx)
  (set-buffer "*scratch*")
  (erase-buffer)
  (pet-movement pet-gfx))

(defun adult-pet-gfx-lookup (alignment skill genus)
  "This function will traverse the uwu-graphics.el adult pet tree
data stucture, and return the list of animation frames for a
particular pet.

The structure of the list is as follows:

LAWFUL (or CHAOTIC)
    - Smart
        - Normie
        - Active
        - Funny
        - Loud
    - Creative
        - Normie
        - Active
        - Funny
        - Loud
    - Social
        - Normie
        - Active
        - Funny
        - Loud

The list can be interpreted like this:

ALIGNMENT
    - Core pet skill
        - 'Genus' of the pet."
      
    (assoc 'gfx
	   (assoc genus
		  (assoc skill
			 (assoc alignment +adult-data+)))))

(defun ())

;;; ╔═════════════════════╗
;;; <@(･ω･o< )@     
;;; ╚═════════════════════╝

;; ┌─┐┌─┐┌─┐┬┌─┌─┐┌─┐┌─┐
;; ├─┘├─┤│  ├┴┐├─┤│ ┬├┤ 
;; ┴  ┴ ┴└─┘┴ ┴┴ ┴└─┘└─┘

;; provide package

(provide 'uwu)